@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: MonadRandom
-version: 0.4.2.2
-id: MonadRandom-0.4.2.2-41c453a4d3603a1aafaf1f31fe6ac694
-key: Monad_HxDS9whmtjz8RSn9ZPpk5g
+version: 0.4.2.3
+id: MonadRandom-0.4.2.3-c1a87dea4099c830800b3ad78538235a
+key: Monad_CLO5AInWsHZAZxUa5zJXgr
 license: OtherLicense
 maintainer: Brent Yorgey <byorgey@gmail.com>
 synopsis: Random-number generation monad.
@@ -15,10 +15,10 @@ exposed: True
 exposed-modules:
     Control.Monad.Random Control.Monad.Random.Class
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/MonadRandom-0.4.2.2
-library-dirs: /usr/lib/ghc-7.10.3/site-local/MonadRandom-0.4.2.2
-data-dir: /usr/share/arm-linux-ghc-7.10.3/MonadRandom-0.4.2.2
-hs-libraries: HSMonadRandom-0.4.2.2-HxDS9whmtjz8RSn9ZPpk5g
+import-dirs: /usr/lib/ghc-7.10.3/site-local/MonadRandom-0.4.2.3
+library-dirs: /usr/lib/ghc-7.10.3/site-local/MonadRandom-0.4.2.3
+data-dir: /usr/share/arm-linux-ghc-7.10.3/MonadRandom-0.4.2.3
+hs-libraries: HSMonadRandom-0.4.2.3-CLO5AInWsHZAZxUa5zJXgr
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
